summaryrefslogtreecommitdiffstats
path: root/src/gvcore
diff options
context:
space:
mode:
Diffstat (limited to 'src/gvcore')
-rw-r--r--src/gvcore/cache.cpp2
-rw-r--r--src/gvcore/cache.h2
-rw-r--r--src/gvcore/captionformatter.cpp2
-rw-r--r--src/gvcore/clicklineedit.cpp8
-rw-r--r--src/gvcore/cursortracker.cpp2
-rw-r--r--src/gvcore/deletedialog.cpp6
-rw-r--r--src/gvcore/deletedialog.h2
-rw-r--r--src/gvcore/deletedialogbase.ui8
-rw-r--r--src/gvcore/document.cpp24
-rw-r--r--src/gvcore/documentloadedimpl.cpp10
-rw-r--r--src/gvcore/documentloadingimpl.cpp2
-rw-r--r--src/gvcore/dragpixmapgenerator.h2
-rw-r--r--src/gvcore/externaltooldialog.cpp2
-rw-r--r--src/gvcore/externaltooldialogbase.ui8
-rw-r--r--src/gvcore/externaltoolmanager.cpp6
-rw-r--r--src/gvcore/filedetailview.cpp8
-rw-r--r--src/gvcore/filedetailviewitem.h2
-rw-r--r--src/gvcore/fileopobject.cpp10
-rw-r--r--src/gvcore/filethumbnailview.cpp12
-rw-r--r--src/gvcore/filethumbnailviewitem.cpp14
-rw-r--r--src/gvcore/filethumbnailviewitem.h2
-rw-r--r--src/gvcore/fileviewcontroller.cpp28
-rw-r--r--src/gvcore/fileviewcontroller.h2
-rw-r--r--src/gvcore/filterbar.ui8
-rw-r--r--src/gvcore/fullscreenbar.cpp8
-rw-r--r--src/gvcore/imageloader.cpp2
-rw-r--r--src/gvcore/imagesavedialog.cpp2
-rw-r--r--src/gvcore/imageview.cpp36
-rw-r--r--src/gvcore/imageviewconfig.kcfg4
-rw-r--r--src/gvcore/imageviewcontroller.cpp8
-rw-r--r--src/gvcore/imageviewtools.cpp2
-rw-r--r--src/gvcore/printdialog.cpp50
-rw-r--r--src/gvcore/printdialogpagebase.ui16
-rw-r--r--src/gvcore/qxcfi.cpp2
-rw-r--r--src/gvcore/thumbnaildetailsdialogbase.ui6
-rw-r--r--src/gvcore/xpm.cpp14
36 files changed, 161 insertions, 161 deletions
diff --git a/src/gvcore/cache.cpp b/src/gvcore/cache.cpp
index 448d8f6..8f4bfb3 100644
--- a/src/gvcore/cache.cpp
+++ b/src/gvcore/cache.cpp
@@ -179,7 +179,7 @@ void Cache::addThumbnail( const KURL& url, const TQPixmap& thumbnail, TQSize ima
checkMaxSize();
}
-void Cache::tqinvalidate( const KURL& url ) {
+void Cache::invalidate( const KURL& url ) {
d->mImages.remove( url );
}
diff --git a/src/gvcore/cache.h b/src/gvcore/cache.h
index 199bc46..68591a5 100644
--- a/src/gvcore/cache.h
+++ b/src/gvcore/cache.h
@@ -52,7 +52,7 @@ public:
void getFrames( const KURL& url, ImageFrames* frames, TQCString* format ) const;
TQPixmap thumbnail( const KURL& url, TQSize& imagesize ) const;
void setPriorityURL( const KURL& url, bool set );
- void tqinvalidate( const KURL& url );
+ void invalidate( const KURL& url );
void checkThumbnailSize( int size );
void readConfig(KConfig*,const TQString& group);
void updateAge();
diff --git a/src/gvcore/captionformatter.cpp b/src/gvcore/captionformatter.cpp
index 74514f3..4b0a593 100644
--- a/src/gvcore/captionformatter.cpp
+++ b/src/gvcore/captionformatter.cpp
@@ -35,7 +35,7 @@ TQString CaptionFormatter::format(const TQString& format) {
TQString resolution;
if (mImageSize.isValid()) {
- resolution = TQString( "%1x%2" ).tqarg( mImageSize.width()).tqarg( mImageSize.height());
+ resolution = TQString( "%1x%2" ).arg( mImageSize.width()).arg( mImageSize.height());
}
TQString str=format;
diff --git a/src/gvcore/clicklineedit.cpp b/src/gvcore/clicklineedit.cpp
index 58c09ac..dfbe3bb 100644
--- a/src/gvcore/clicklineedit.cpp
+++ b/src/gvcore/clicklineedit.cpp
@@ -40,14 +40,14 @@ ClickLineEdit::ClickLineEdit(TQWidget *parent, const char* name ) :
void ClickLineEdit::setClickMessage( const TQString &msg )
{
mClickMessage = msg;
- tqrepaint();
+ repaint();
}
void ClickLineEdit::setText( const TQString &txt )
{
mDrawClickMsg = txt.isEmpty();
- tqrepaint();
+ repaint();
KLineEdit::setText( txt );
}
@@ -86,7 +86,7 @@ void ClickLineEdit::focusInEvent( TQFocusEvent *ev )
{
if ( mDrawClickMsg == true ) {
mDrawClickMsg = false;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusInEvent( ev );
}
@@ -96,7 +96,7 @@ void ClickLineEdit::focusOutEvent( TQFocusEvent *ev )
{
if ( text().isEmpty() ) {
mDrawClickMsg = true;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusOutEvent( ev );
}
diff --git a/src/gvcore/cursortracker.cpp b/src/gvcore/cursortracker.cpp
index 00f1736..3569dc8 100644
--- a/src/gvcore/cursortracker.cpp
+++ b/src/gvcore/cursortracker.cpp
@@ -79,7 +79,7 @@ TipTracker::TipTracker(const TQString& txt, TQWidget* reference)
setPalette(TQToolTip::palette());
setFrameStyle(TQFrame::Plain | TQFrame::Box);
setLineWidth(1);
- tqsetAlignment(AlignAuto | AlignTop);
+ setAlignment(AlignAuto | AlignTop);
}
diff --git a/src/gvcore/deletedialog.cpp b/src/gvcore/deletedialog.cpp
index 3d6308b..2e3cfbb 100644
--- a/src/gvcore/deletedialog.cpp
+++ b/src/gvcore/deletedialog.cpp
@@ -26,7 +26,7 @@
#include <tqstringlist.h>
#include <tqcheckbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqtimer.h>
#include <tqvbox.h>
@@ -113,9 +113,9 @@ bool DeleteDialog::shouldDelete() const {
}
-TQSize DeleteDialog::tqsizeHint() const {
+TQSize DeleteDialog::sizeHint() const {
m_widget->adjustSize();
- TQSize hint = m_widget->tqminimumSize();
+ TQSize hint = m_widget->minimumSize();
hint = calculateSize(hint.width(), hint.height());
// For some reason calculateSize does not return a correct height. As I'm
diff --git a/src/gvcore/deletedialog.h b/src/gvcore/deletedialog.h
index 6825368..1bdc5ab 100644
--- a/src/gvcore/deletedialog.h
+++ b/src/gvcore/deletedialog.h
@@ -36,7 +36,7 @@ public:
void setURLList(const KURL::List &files);
bool shouldDelete() const;
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
protected slots:
virtual void accept();
diff --git a/src/gvcore/deletedialogbase.ui b/src/gvcore/deletedialogbase.ui
index 4725920..7a8ffd4 100644
--- a/src/gvcore/deletedialogbase.ui
+++ b/src/gvcore/deletedialogbase.ui
@@ -21,7 +21,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<hbox>
<property name="name">
@@ -47,7 +47,7 @@
<property name="name">
<cstring>ddDeleteText</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>60</height>
@@ -56,7 +56,7 @@
<property name="text">
<string>Deletion method placeholder, not in GUI</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignCenter</set>
</property>
</widget>
@@ -80,7 +80,7 @@
<property name="text">
<string>Placeholder for number of files, not in GUI</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
</widget>
diff --git a/src/gvcore/document.cpp b/src/gvcore/document.cpp
index caa93f5..b81a229 100644
--- a/src/gvcore/document.cpp
+++ b/src/gvcore/document.cpp
@@ -343,7 +343,7 @@ void Document::slotLoaded() {
//
//---------------------------------------------------------------------
void Document::reload() {
- Cache::instance()->tqinvalidate( url());
+ Cache::instance()->invalidate( url());
load();
emit reloaded(url());
}
@@ -378,7 +378,7 @@ void Document::doPaint(KPrinter *printer, TQPainter *painter) {
TQString t = "true";
TQString f = "false";
- int tqalignment = (printer->option("app-gwenview-position").isEmpty() ?
+ int alignment = (printer->option("app-gwenview-position").isEmpty() ?
TQt::AlignCenter : printer->option("app-gwenview-position").toInt());
// Compute filename offset
@@ -407,7 +407,7 @@ void Document::doPaint(KPrinter *printer, TQPainter *painter) {
if (scaling==GV_FITTOPAGE /* Fit to page */) {
bool enlargeToFit = printer->option( "app-gwenview-enlargeToFit" ) != f;
if ((image.width() > pdWidth || image.height() > pdHeight) || enlargeToFit) {
- size.tqscale( pdWidth, pdHeight, TQSize::ScaleMin );
+ size.scale( pdWidth, pdHeight, TQSize::ScaleMin );
}
} else {
if (scaling==GV_SCALE /* Scale To */) {
@@ -452,24 +452,24 @@ void Document::doPaint(KPrinter *printer, TQPainter *painter) {
printer->abort();
return;
} else if (resp == KMessageBox::No) { // Shrink
- size.tqscale(pdWidth, pdHeight, TQSize::ScaleMin);
+ size.scale(pdWidth, pdHeight, TQSize::ScaleMin);
}
}
}
// Compute x and y
- if ( tqalignment & TQt::AlignHCenter )
+ if ( alignment & TQt::AlignHCenter )
x = (pdWidth - size.width())/2;
- else if ( tqalignment & TQt::AlignLeft )
+ else if ( alignment & TQt::AlignLeft )
x = 0;
- else if ( tqalignment & TQt::AlignRight )
+ else if ( alignment & TQt::AlignRight )
x = pdWidth - size.width();
- if ( tqalignment & TQt::AlignVCenter )
+ if ( alignment & TQt::AlignVCenter )
y = (pdHeight - size.height())/2;
- else if ( tqalignment & TQt::AlignTop )
+ else if ( alignment & TQt::AlignTop )
y = 0;
- else if ( tqalignment & TQt::AlignBottom )
+ else if ( alignment & TQt::AlignBottom )
y = pdHeight - size.height();
// Draw, the image will be scaled to fit the given area if necessary
@@ -532,7 +532,7 @@ void Document::saveBeforeClosing() {
if (!d->mModified) return;
TQString msg=i18n("<qt>The image <b>%1</b> has been modified, do you want to save the changes?</qt>")
- .tqarg(url().prettyURL());
+ .arg(url().prettyURL());
int result=KMessageBox::questionYesNo(dialogParentWidget(), msg, TQString(),
KStdGuiItem::save(), KStdGuiItem::discard(), CONFIG_SAVE_AUTOMATICALLY);
@@ -605,7 +605,7 @@ TQString Document::saveInternal(const KURL& url, const TQCString& format) {
LOG("Save failed: " << msg);
return TQString("<qt><b>%1</b><br/>")
- .tqarg(i18n("Could not save the image to %1.").tqarg(url.prettyURL()))
+ .arg(i18n("Could not save the image to %1.").arg(url.prettyURL()))
+ msg + "</qt>";
}
diff --git a/src/gvcore/documentloadedimpl.cpp b/src/gvcore/documentloadedimpl.cpp
index aacea94..31baec0 100644
--- a/src/gvcore/documentloadedimpl.cpp
+++ b/src/gvcore/documentloadedimpl.cpp
@@ -134,7 +134,7 @@ TQString DocumentLoadedImpl::save(const KURL& _url, const TQCString& format) con
if (!parent.isWritable()) {
return
i18n("The %1 folder is read-only.")
- .tqarg(parent.filePath());
+ .arg(parent.filePath());
}
}
}
@@ -152,7 +152,7 @@ TQString DocumentLoadedImpl::save(const KURL& _url, const TQCString& format) con
if (tmp.status()!=0) {
TQString reason( strerror(tmp.status()) );
return i18n("Could not create a temporary file.\nReason: %1.")
- .tqarg(reason);
+ .arg(reason);
}
TQFile* file=tmp.file();
msg=localSave(file, format);
@@ -162,7 +162,7 @@ TQString DocumentLoadedImpl::save(const KURL& _url, const TQCString& format) con
if (tmp.status()!=0) {
TQString reason( strerror(tmp.status()) );
return i18n("Saving image to a temporary file failed.\nReason: %1.")
- .tqarg(reason);
+ .arg(reason);
}
TQString tmpName=tmp.name();
@@ -172,11 +172,11 @@ TQString DocumentLoadedImpl::save(const KURL& _url, const TQCString& format) con
// Move the tmp file to the final dest
if (url.isLocalFile()) {
if( ::rename( TQFile::encodeName(tmpName), TQFile::encodeName( url.path())) < 0 ) {
- return i18n("Could not write to %1.").tqarg(url.path());
+ return i18n("Could not write to %1.").arg(url.path());
}
} else {
if (!KIO::NetAccess::upload(tmp.name(), url, KApplication::kApplication()->mainWidget() )) {
- return i18n("Could not upload the file to %1.").tqarg(url.prettyURL());
+ return i18n("Could not upload the file to %1.").arg(url.prettyURL());
}
}
diff --git a/src/gvcore/documentloadingimpl.cpp b/src/gvcore/documentloadingimpl.cpp
index 072229e..02020ad 100644
--- a/src/gvcore/documentloadingimpl.cpp
+++ b/src/gvcore/documentloadingimpl.cpp
@@ -99,7 +99,7 @@ void DocumentLoadingImpl::init() {
emitImageRectUpdated();
} else {
setImage(image);
- TQMemArray< TQRect > rects = TQRegion(d->mLoader->loadedRegion()).tqrects();
+ TQMemArray< TQRect > rects = TQRegion(d->mLoader->loadedRegion()).rects();
for( unsigned int i = 0; i < rects.count(); ++i ) {
emit rectUpdated(rects[i]);
}
diff --git a/src/gvcore/dragpixmapgenerator.h b/src/gvcore/dragpixmapgenerator.h
index efbbd93..308c391 100644
--- a/src/gvcore/dragpixmapgenerator.h
+++ b/src/gvcore/dragpixmapgenerator.h
@@ -128,7 +128,7 @@ public:
if (listCropped) {
// If list has been cropped, leave space for item count text
height += fm.height();
- bottomText = i18n("%1 items").tqarg(mItemList.count());
+ bottomText = i18n("%1 items").arg(mItemList.count());
width = TQMAX(width, fm.width("... " + bottomText));
}
diff --git a/src/gvcore/externaltooldialog.cpp b/src/gvcore/externaltooldialog.cpp
index e579b99..a71351b 100644
--- a/src/gvcore/externaltooldialog.cpp
+++ b/src/gvcore/externaltooldialog.cpp
@@ -144,7 +144,7 @@ struct ExternalToolDialogPrivate {
for (; item; item=item->nextSibling()) {
if (item==mSelectedItem) continue;
if (name==item->text(0)) {
- KMessageBox::sorry(mContent, i18n("There is already a tool named \"%1\"").tqarg(name));
+ KMessageBox::sorry(mContent, i18n("There is already a tool named \"%1\"").arg(name));
return false;
}
}
diff --git a/src/gvcore/externaltooldialogbase.ui b/src/gvcore/externaltooldialogbase.ui
index 00d2954..e35f222 100644
--- a/src/gvcore/externaltooldialogbase.ui
+++ b/src/gvcore/externaltooldialogbase.ui
@@ -20,7 +20,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>720</width>
<height>0</height>
@@ -49,7 +49,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>487</width>
<height>16</height>
@@ -153,7 +153,7 @@
</widget>
<widget class="TQLayoutWidget" row="0" column="0">
<property name="name">
- <cstring>tqlayout3</cstring>
+ <cstring>layout3</cstring>
</property>
<grid>
<property name="name">
@@ -304,7 +304,7 @@ You can use keywords in the Command field:
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>140</height>
diff --git a/src/gvcore/externaltoolmanager.cpp b/src/gvcore/externaltoolmanager.cpp
index 4fd4e03..3a43d26 100644
--- a/src/gvcore/externaltoolmanager.cpp
+++ b/src/gvcore/externaltoolmanager.cpp
@@ -222,7 +222,7 @@ TQDict<KDesktopFile>& ExternalToolManager::desktopFiles() const {
void ExternalToolManager::hideDesktopFile(KDesktopFile* desktopFile) {
TQFileInfo fi(desktopFile->fileName());
- TQString name=TQString("%1.desktop").tqarg( fi.baseName(true) );
+ TQString name=TQString("%1.desktop").arg( fi.baseName(true) );
d->mDesktopFiles.take(name);
if (desktopFile->isReadOnly()) {
@@ -240,7 +240,7 @@ KDesktopFile* ExternalToolManager::editSystemDesktopFile(const KDesktopFile* des
TQFileInfo fi(desktopFile->fileName());
TQString name=fi.baseName(true);
- d->mDesktopFiles.remove(TQString("%1.desktop").tqarg(name));
+ d->mDesktopFiles.remove(TQString("%1.desktop").arg(name));
return createUserDesktopFile(name);
}
@@ -250,7 +250,7 @@ KDesktopFile* ExternalToolManager::createUserDesktopFile(const TQString& name) {
Q_ASSERT(!name.isEmpty());
KDesktopFile* desktopFile=new KDesktopFile(
d->mUserToolDir + "/" + name + ".desktop", false);
- d->mDesktopFiles.insert(TQString("%1.desktop").tqarg(name), desktopFile);
+ d->mDesktopFiles.insert(TQString("%1.desktop").arg(name), desktopFile);
return desktopFile;
}
diff --git a/src/gvcore/filedetailview.cpp b/src/gvcore/filedetailview.cpp
index f061c13..a7d9f64 100644
--- a/src/gvcore/filedetailview.cpp
+++ b/src/gvcore/filedetailview.cpp
@@ -125,8 +125,8 @@ FileDetailView::FileDetailView(TQWidget *parent, const char *name)
setDropHighlighter(false);
int size = IconSize(KIcon::Small);
- mShownItemUnselectedPixmap = createShownItemPixmap(size, tqcolorGroup().highlight());
- mShownItemSelectedPixmap = createShownItemPixmap(size, tqcolorGroup().highlightedText());
+ mShownItemUnselectedPixmap = createShownItemPixmap(size, colorGroup().highlight());
+ mShownItemSelectedPixmap = createShownItemPixmap(size, colorGroup().highlightedText());
}
@@ -525,8 +525,8 @@ void FileDetailView::setShownFileItem(KFileItem* fileItem)
FileDetailViewItem* newShownItem=viewItem(fileItem);
FileViewBase::setShownFileItem(fileItem);
- if (oldShownItem) oldShownItem->tqrepaint();
- if (newShownItem) newShownItem->tqrepaint();
+ if (oldShownItem) oldShownItem->repaint();
+ if (newShownItem) newShownItem->repaint();
}
diff --git a/src/gvcore/filedetailviewitem.h b/src/gvcore/filedetailviewitem.h
index 1104bce..a0ad5df 100644
--- a/src/gvcore/filedetailviewitem.h
+++ b/src/gvcore/filedetailviewitem.h
@@ -71,7 +71,7 @@ public:
TQRect rect() const
{
- TQRect r = listView()->tqitemRect(this);
+ TQRect r = listView()->itemRect(this);
return TQRect( listView()->viewportToContents( r.topLeft() ),
TQSize( r.width(), r.height() ) );
}
diff --git a/src/gvcore/fileopobject.cpp b/src/gvcore/fileopobject.cpp
index e72d192..5d9a820 100644
--- a/src/gvcore/fileopobject.cpp
+++ b/src/gvcore/fileopobject.cpp
@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
// TQt
#include <tqfile.h>
-#include <tqstylesheet.h>
+#include <stylesheet.h>
#include <tqwidget.h>
// KDE
@@ -89,7 +89,7 @@ void FileOpObject::slotResult(KIO::Job* job) {
void FileOpObject::polishJob(KIO::Job* job) {
- job->setWindow(mParent->tqtopLevelWidget());
+ job->setWindow(mParent->topLevelWidget());
connect( job, TQT_SIGNAL( result(KIO::Job*) ),
this, TQT_SLOT( slotResult(KIO::Job*) ) );
}
@@ -259,7 +259,7 @@ void FileOpTrashObject::operator()() {
} else {
TQString filename=TQStyleSheet::escape(mURLList.first().filename());
response=KMessageBox::warningContinueCancel(mParent,
- i18n("<p>Do you really want to move <b>%1</b> to the trash?</p>").tqarg(filename),i18n("Trash used as a verb", "Trash File"),KGuiItem(i18n("Trash used as a verb", "&Trash"),"edittrash"));
+ i18n("<p>Do you really want to move <b>%1</b> to the trash?</p>").arg(filename),i18n("Trash used as a verb", "Trash File"),KGuiItem(i18n("Trash used as a verb", "&Trash"),"edittrash"));
}
if (response!=KMessageBox::Continue) return;
}
@@ -287,7 +287,7 @@ void FileOpRealDeleteObject::operator()() {
} else {
TQString filename=TQStyleSheet::escape(mURLList.first().filename());
response=KMessageBox::warningContinueCancel(mParent,
- i18n("<p>Do you really want to delete <b>%1</b>?</p>").tqarg(filename),
+ i18n("<p>Do you really want to delete <b>%1</b>?</p>").arg(filename),
i18n("Delete File"),
KStdGuiItem::del()
);
@@ -309,7 +309,7 @@ void FileOpRenameObject::operator()() {
TQString filename = srcURL.filename();
InputDialog dlg(mParent);
dlg.setCaption(i18n("Renaming File"));
- dlg.setLabel(i18n("<p>Rename file <b>%1</b> to:</p>").tqarg(TQStyleSheet::escape(filename)));
+ dlg.setLabel(i18n("<p>Rename file <b>%1</b> to:</p>").arg(TQStyleSheet::escape(filename)));
dlg.setButtonOK( KGuiItem(i18n("&Rename"), "edit") );
dlg.lineEdit()->setText(filename);
diff --git a/src/gvcore/filethumbnailview.cpp b/src/gvcore/filethumbnailview.cpp
index 51445be..cc338ca 100644
--- a/src/gvcore/filethumbnailview.cpp
+++ b/src/gvcore/filethumbnailview.cpp
@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
// TQt
#include <tqframe.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqpen.h>
#include <tqpixmap.h>
@@ -77,8 +77,8 @@ public:
ProgressWidget(FileThumbnailView* view, int count)
: TQFrame(view)
{
- TQHBoxLayout* tqlayout=new TQHBoxLayout(this, 3, 3);
- tqlayout->setAutoAdd(true);
+ TQHBoxLayout* layout=new TQHBoxLayout(this, 3, 3);
+ layout->setAutoAdd(true);
setFrameStyle( TQFrame::StyledPanel | TQFrame::Raised );
mStop=new TQPushButton(this);
@@ -93,7 +93,7 @@ public:
void polish() {
TQFrame::polish();
- setMinimumWidth(tqlayout()->tqminimumSize().width());
+ setMinimumWidth(layout()->minimumSize().width());
//setFixedHeight( mProgressBar->height() );
setFixedHeight( mStop->height() );
}
@@ -142,7 +142,7 @@ struct FileThumbnailView::Private {
mWaitThumbnail.fill(view->paletteBackgroundColor());
TQPainter painter(&mWaitThumbnail);
- painter.setPen(view->tqcolorGroup().button());
+ painter.setPen(view->colorGroup().button());
painter.drawRect(0,0,mThumbnailSize,mThumbnailSize);
painter.drawPixmap(
(mThumbnailSize-mWaitPixmap.width())/2,
@@ -285,7 +285,7 @@ void FileThumbnailView::setThumbnailPixmap(const KFileItem* fileItem, const TQPi
if (size.isValid()) {
iconItem->setImageSize(size);
}
- iconItem->tqrepaint();
+ iconItem->repaint();
// Notify progress
if (d->mProgressWidget) {
diff --git a/src/gvcore/filethumbnailviewitem.cpp b/src/gvcore/filethumbnailviewitem.cpp
index 65da494..cd607b7 100644
--- a/src/gvcore/filethumbnailviewitem.cpp
+++ b/src/gvcore/filethumbnailviewitem.cpp
@@ -271,16 +271,16 @@ void FileThumbnailViewItem::calcRect(const TQString&) {
textH+=(*it)->height();
}
- TQRect tqitemRect(x(), y(), view->gridX(), 0);
+ TQRect itemRect(x(), y(), view->gridX(), 0);
TQRect itemPixmapRect(PADDING, PADDING, thumbnailSize, thumbnailSize);
TQRect itemTextRect(0, 0, textW, textH);
if (isRight) {
- tqitemRect.setHeight( TQMAX(thumbnailSize + PADDING*2, textH) );
+ itemRect.setHeight( TQMAX(thumbnailSize + PADDING*2, textH) );
itemTextRect.moveLeft(thumbnailSize + PADDING * 2 );
- itemTextRect.moveTop((tqitemRect.height() - textH)/2);
+ itemTextRect.moveTop((itemRect.height() - textH)/2);
} else {
- itemPixmapRect.moveLeft( (tqitemRect.width() - itemPixmapRect.width()) / 2 );
- tqitemRect.setHeight(thumbnailSize + PADDING*3 + textH);
+ itemPixmapRect.moveLeft( (itemRect.width() - itemPixmapRect.width()) / 2 );
+ itemRect.setHeight(thumbnailSize + PADDING*3 + textH);
itemTextRect.moveLeft(PADDING);
itemTextRect.moveTop(thumbnailSize + PADDING * 2);
}
@@ -292,8 +292,8 @@ void FileThumbnailViewItem::calcRect(const TQString&) {
if ( itemTextRect != textRect() ) {
setTextRect( itemTextRect );
}
- if ( tqitemRect != rect() ) {
- setItemRect( tqitemRect );
+ if ( itemRect != rect() ) {
+ setItemRect( itemRect );
}
}
diff --git a/src/gvcore/filethumbnailviewitem.h b/src/gvcore/filethumbnailviewitem.h
index b242355..d3a1063 100644
--- a/src/gvcore/filethumbnailviewitem.h
+++ b/src/gvcore/filethumbnailviewitem.h
@@ -52,7 +52,7 @@ public:
void updateLines();
protected:
- void paintItem(TQPainter* painter, const TQColorGroup& tqcolorGroup);
+ void paintItem(TQPainter* painter, const TQColorGroup& colorGroup);
void calcRect( const TQString& text_=TQString() );
void paintFocus(TQPainter*, const TQColorGroup&) {}
bool acceptDrop(const TQMimeSource*) const;
diff --git a/src/gvcore/fileviewcontroller.cpp b/src/gvcore/fileviewcontroller.cpp
index bdacf01..7222c27 100644
--- a/src/gvcore/fileviewcontroller.cpp
+++ b/src/gvcore/fileviewcontroller.cpp
@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#include <tqcheckbox.h>
#include <tqdatetimeedit.h>
#include <tqhbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpopupmenu.h>
#include <tqpushbutton.h>
#include <tqtooltip.h>
@@ -191,7 +191,7 @@ public:
void initFilterBar() {
mFilterBar=new FilterBar(that);
- mFilterBar->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
+ mFilterBar->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Fixed);
mFilterBar->hide();
TQIconSet resetIS=BarIcon("locationbar_erase");
@@ -256,7 +256,7 @@ FileViewController::FileViewController(TQWidget* parent,KActionCollection* actio
: TQWidget(parent)
, mMode(FILE_LIST)
, mPrefetch( NULL )
-, mChangeDirtqStatus(CHANGE_DIR_STATUS_NONE)
+, mChangeDirStatus(CHANGE_DIR_STATUS_NONE)
, mBrowsing(false)
, mSelecting(false)
{
@@ -268,10 +268,10 @@ FileViewController::FileViewController(TQWidget* parent,KActionCollection* actio
d->initFilterCombo();
d->mStack=new TQWidgetStack(this);
- TQVBoxLayout *tqlayout=new TQVBoxLayout(this);
- tqlayout->addWidget(d->mToolBar);
- tqlayout->addWidget(d->mFilterBar);
- tqlayout->addWidget(d->mStack);
+ TQVBoxLayout *layout=new TQVBoxLayout(this);
+ layout->addWidget(d->mToolBar);
+ layout->addWidget(d->mFilterBar);
+ layout->addWidget(d->mStack);
// Actions
mSelectFirst=new KAction(i18n("&First"),
@@ -338,7 +338,7 @@ FileViewController::FileViewController(TQWidget* parent,KActionCollection* actio
// Dir lister
mDirLister=new DirLister;
- mDirLister->setMainWindow(tqtopLevelWidget());
+ mDirLister->setMainWindow(topLevelWidget());
connect(mDirLister,TQT_SIGNAL(clear()),
TQT_TQOBJECT(this),TQT_SLOT(dirListerClear()) );
@@ -575,13 +575,13 @@ void FileViewController::slotSelectNext() {
}
void FileViewController::slotSelectPreviousDir() {
- mChangeDirtqStatus = CHANGE_DIR_STATUS_PREV;
+ mChangeDirStatus = CHANGE_DIR_STATUS_PREV;
mDirLister->clearError();
mDirLister->openURL(mDirURL.upURL());
}
void FileViewController::slotSelectNextDir() {
- mChangeDirtqStatus = CHANGE_DIR_STATUS_NEXT;
+ mChangeDirStatus = CHANGE_DIR_STATUS_NEXT;
mDirLister->clearError();
mDirLister->openURL(mDirURL.upURL());
}
@@ -747,7 +747,7 @@ void FileViewController::updateViewMode() {
void FileViewController::updateThumbnailSize(int size) {
size*=SLIDER_RESOLUTION;
- d->mSliderTracker->setText(i18n("Thumbnail size: %1x%2").tqarg(size).tqarg(size));
+ d->mSliderTracker->setText(i18n("Thumbnail size: %1x%2").arg(size).arg(size));
FileViewConfig::setThumbnailSize(size);
mFileThumbnailView->setThumbnailSize(size);
Cache::instance()->checkThumbnailSize(size);
@@ -1102,12 +1102,12 @@ void FileViewController::delayedDirListerCompleted() {
mFileThumbnailView->sort(mFileThumbnailView->sortDirection());
}
- if (mChangeDirtqStatus != CHANGE_DIR_STATUS_NONE) {
+ if (mChangeDirStatus != CHANGE_DIR_STATUS_NONE) {
KFileItem *item;
TQString fileName = mDirURL.filename();
for (item=currentFileView()->firstFileItem(); item; item=currentFileView()->nextItem(item) ) {
if (item->name() == fileName) {
- if (mChangeDirtqStatus == CHANGE_DIR_STATUS_NEXT) {
+ if (mChangeDirStatus == CHANGE_DIR_STATUS_NEXT) {
do {
item=currentFileView()->nextItem(item);
} while (item && !Archive::fileItemIsDirOrArchive(item));
@@ -1119,7 +1119,7 @@ void FileViewController::delayedDirListerCompleted() {
break;
};
}
- mChangeDirtqStatus = CHANGE_DIR_STATUS_NONE;
+ mChangeDirStatus = CHANGE_DIR_STATUS_NONE;
if (!item) {
mDirLister->openURL(mDirURL);
} else {
diff --git a/src/gvcore/fileviewcontroller.h b/src/gvcore/fileviewcontroller.h
index de0de53..8339659 100644
--- a/src/gvcore/fileviewcontroller.h
+++ b/src/gvcore/fileviewcontroller.h
@@ -227,7 +227,7 @@ private:
CHANGE_DIR_STATUS_NONE,
CHANGE_DIR_STATUS_PREV,
CHANGE_DIR_STATUS_NEXT
- } mChangeDirtqStatus;
+ } mChangeDirStatus;
bool mBrowsing;
bool mSelecting;
diff --git a/src/gvcore/filterbar.ui b/src/gvcore/filterbar.ui
index b407ce1..2c9f11c 100644
--- a/src/gvcore/filterbar.ui
+++ b/src/gvcore/filterbar.ui
@@ -64,7 +64,7 @@
<property name="sizeType">
<enum>Maximum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>16</height>
@@ -125,7 +125,7 @@ equal to this date</string>
<property name="sizeType">
<enum>Maximum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>16</height>
@@ -185,7 +185,7 @@ equal to this date</string>
<property name="sizeType">
<enum>Maximum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>16</height>
@@ -210,7 +210,7 @@ equal to this date</string>
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>16</height>
diff --git a/src/gvcore/fullscreenbar.cpp b/src/gvcore/fullscreenbar.cpp
index 311b98d..d288429 100644
--- a/src/gvcore/fullscreenbar.cpp
+++ b/src/gvcore/fullscreenbar.cpp
@@ -21,7 +21,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
// TQt
#include <tqbitmap.h>
#include <tqevent.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqtimer.h>
@@ -83,8 +83,8 @@ FullScreenBar::FullScreenBar(TQWidget* parent)
setIconSize(FULLSCREEN_ICON_SIZE);
setMovingEnabled(false);
- TQColor bg=tqcolorGroup().highlight();
- TQColor fg=tqcolorGroup().highlightedText();
+ TQColor bg=colorGroup().highlight();
+ TQColor fg=colorGroup().highlightedText();
TQPalette pal(palette());
pal.setColor(TQColorGroup::Background, bg);
pal.setColor(TQColorGroup::Foreground, fg);
@@ -123,7 +123,7 @@ void FullScreenBar::showEvent(TQShowEvent* event) {
if (!d->mFirstShow) return;
d->mFirstShow=false;
move(0, -height());
- tqlayout()->setResizeMode(TQLayout::Fixed);
+ layout()->setResizeMode(TQLayout::Fixed);
}
diff --git a/src/gvcore/imageloader.cpp b/src/gvcore/imageloader.cpp
index 06a9011..699d088 100644
--- a/src/gvcore/imageloader.cpp
+++ b/src/gvcore/imageloader.cpp
@@ -113,7 +113,7 @@ public:
int getch() {
if (mThread->testCancel()) {
LOG("cancel detected");
- setqStatus(IO_ReadError);
+ seStatus(IO_ReadError);
return -1;
}
return TQBuffer::getch();
diff --git a/src/gvcore/imagesavedialog.cpp b/src/gvcore/imagesavedialog.cpp
index 7831830..17101e2 100644
--- a/src/gvcore/imagesavedialog.cpp
+++ b/src/gvcore/imagesavedialog.cpp
@@ -70,7 +70,7 @@ ImageSaveDialog::ImageSaveDialog(KURL& url, const TQCString& imageFormat, TQWidg
if (!patterns.contains(pattern)) patterns.append(pattern);
}
if (patterns.isEmpty()) {
- patterns.append( TQString("*.%1").tqarg(format.lower()) );
+ patterns.append( TQString("*.%1").arg(format.lower()) );
}
TQString patternString=patterns.join(" ");
diff --git a/src/gvcore/imageviewconfig.kcfg b/src/gvcore/imageviewconfig.kcfg
index 6424202..d93051a 100644
--- a/src/gvcore/imageviewconfig.kcfg
+++ b/src/gvcore/imageviewconfig.kcfg
@@ -2,7 +2,7 @@
<!DOCTYPE kcfg SYSTEM "http://www.kde.org/standards/kcfg/1.0/kcfg.dtd">
<kcfg>
<include>tqapplication.h</include>
- <include>tqpalette.h</include>
+ <include>palette.h</include>
<kcfgfile name="gwenviewrc"/>
<group name="pixmap widget">
<entry name="smoothAlgorithm" key="smooth scale" type="Enum">
@@ -18,7 +18,7 @@
<default>false</default>
</entry>
<entry name="backgroundColor" key="background color" type="Color">
- <default code="true">TQApplication::tqpalette().active().dark()</default>
+ <default code="true">TQApplication::palette().active().dark()</default>
</entry>
<entry name="enlargeSmallImages" key="enlarge small images" type="Bool">
<default>false</default>
diff --git a/src/gvcore/imageviewcontroller.cpp b/src/gvcore/imageviewcontroller.cpp
index f24a2e8..8293b44 100644
--- a/src/gvcore/imageviewcontroller.cpp
+++ b/src/gvcore/imageviewcontroller.cpp
@@ -22,7 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
// TQt
#include <tqcursor.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpopupmenu.h>
#include <tqvbox.h>
#include <tqwidgetstack.h>
@@ -275,12 +275,12 @@ ImageViewController::ImageViewController(TQWidget* parent, Document* document, K
d->mContainer=new TQWidget(parent);
d->mContainer->setMinimumWidth(1); // Make sure we can resize the toolbar smaller than its minimum size
- TQVBoxLayout* tqlayout=new TQVBoxLayout(d->mContainer);
+ TQVBoxLayout* layout=new TQVBoxLayout(d->mContainer);
d->mToolBar=new KToolBar(d->mContainer, "", true);
- tqlayout->add(d->mToolBar);
+ layout->add(d->mToolBar);
d->mStack=new TQWidgetStack(d->mContainer);
- tqlayout->add(d->mStack);
+ layout->add(d->mStack);
d->mImageView=new ImageView(d->mStack, document, actionCollection);
d->mStack->addWidget(d->mImageView);
diff --git a/src/gvcore/imageviewtools.cpp b/src/gvcore/imageviewtools.cpp
index 699868a..da9044a 100644
--- a/src/gvcore/imageviewtools.cpp
+++ b/src/gvcore/imageviewtools.cpp
@@ -36,7 +36,7 @@ namespace Gwenview {
// Helper function
static TQCursor loadCursor(const TQString& name) {
TQString path;
- path=locate("data", TQString("gwenview/cursors/%1.png").tqarg(name));
+ path=locate("data", TQString("gwenview/cursors/%1.png").arg(name));
return TQCursor(TQPixmap(path));
}
diff --git a/src/gvcore/printdialog.cpp b/src/gvcore/printdialog.cpp
index 98524af..1f07979 100644
--- a/src/gvcore/printdialog.cpp
+++ b/src/gvcore/printdialog.cpp
@@ -20,7 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
// TQt
#include <tqcheckbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqradiobutton.h>
#include <tqvbuttongroup.h>
@@ -82,8 +82,8 @@ PrintDialogPage::PrintDialogPage( Document* document, TQWidget *parent, const ch
mContent = new PrintDialogPageBase(this);
setTitle( mContent->caption() );
- TQVBoxLayout *tqlayout = new TQVBoxLayout( this );
- tqlayout->addWidget( mContent );
+ TQVBoxLayout *layout = new TQVBoxLayout( this );
+ layout->addWidget( mContent );
connect(mContent->mWidth, TQT_SIGNAL( valueChanged( double )), TQT_SLOT( slotWidthChanged( double )));
connect(mContent->mHeight, TQT_SIGNAL( valueChanged( double )), TQT_SLOT( slotHeightChanged( double )));
@@ -169,57 +169,57 @@ void PrintDialogPage::setScaleHeight( double value ) {
}
int PrintDialogPage::getPosition(const TQString& align) {
- int tqalignment;
+ int alignment;
if (align == i18n("Central-Left")) {
- tqalignment = TQt::AlignLeft | TQt::AlignVCenter;
+ alignment = TQt::AlignLeft | TQt::AlignVCenter;
} else if (align == i18n("Central-Right")) {
- tqalignment = TQt::AlignRight | TQt::AlignVCenter;
+ alignment = TQt::AlignRight | TQt::AlignVCenter;
} else if (align == i18n("Top-Left")) {
- tqalignment = TQt::AlignTop | TQt::AlignLeft;
+ alignment = TQt::AlignTop | TQt::AlignLeft;
} else if (align == i18n("Top-Right")) {
- tqalignment = TQt::AlignTop | TQt::AlignRight;
+ alignment = TQt::AlignTop | TQt::AlignRight;
} else if (align == i18n("Bottom-Left")) {
- tqalignment = TQt::AlignBottom | TQt::AlignLeft;
+ alignment = TQt::AlignBottom | TQt::AlignLeft;
} else if (align == i18n("Bottom-Right")) {
- tqalignment = TQt::AlignBottom | TQt::AlignRight;
+ alignment = TQt::AlignBottom | TQt::AlignRight;
} else if (align == i18n("Top-Central")) {
- tqalignment = TQt::AlignTop | TQt::AlignHCenter;
+ alignment = TQt::AlignTop | TQt::AlignHCenter;
} else if (align == i18n("Bottom-Central")) {
- tqalignment = TQt::AlignBottom | TQt::AlignHCenter;
+ alignment = TQt::AlignBottom | TQt::AlignHCenter;
} else {
// Central
- tqalignment = TQt::AlignCenter; // TQt::AlignHCenter || TQt::AlignVCenter
+ alignment = TQt::AlignCenter; // TQt::AlignHCenter || TQt::AlignVCenter
}
- return tqalignment;
+ return alignment;
}
TQString PrintDialogPage::setPosition(int align) {
- TQString tqalignment;
+ TQString alignment;
if (align == (TQt::AlignLeft | TQt::AlignVCenter)) {
- tqalignment = i18n("Central-Left");
+ alignment = i18n("Central-Left");
} else if (align == (TQt::AlignRight | TQt::AlignVCenter)) {
- tqalignment = i18n("Central-Right");
+ alignment = i18n("Central-Right");
} else if (align == (TQt::AlignTop | TQt::AlignLeft)) {
- tqalignment = i18n("Top-Left");
+ alignment = i18n("Top-Left");
} else if (align == (TQt::AlignTop | TQt::AlignRight)) {
- tqalignment = i18n("Top-Right");
+ alignment = i18n("Top-Right");
} else if (align == (TQt::AlignBottom | TQt::AlignLeft)) {
- tqalignment = i18n("Bottom-Left");
+ alignment = i18n("Bottom-Left");
} else if (align == (TQt::AlignBottom | TQt::AlignRight)) {
- tqalignment = i18n("Bottom-Right");
+ alignment = i18n("Bottom-Right");
} else if (align == (TQt::AlignTop | TQt::AlignHCenter)) {
- tqalignment = i18n("Top-Central");
+ alignment = i18n("Top-Central");
} else if (align == (TQt::AlignBottom | TQt::AlignHCenter)) {
- tqalignment = i18n("Bottom-Central");
+ alignment = i18n("Bottom-Central");
} else {
// Central: TQt::AlignCenter or (TQt::AlignHCenter || TQt::AlignVCenter)
- tqalignment = i18n("Central");
+ alignment = i18n("Central");
}
- return tqalignment;
+ return alignment;
}
// SLOTS
diff --git a/src/gvcore/printdialogpagebase.ui b/src/gvcore/printdialogpagebase.ui
index 6d92eda..6ae7696 100644
--- a/src/gvcore/printdialogpagebase.ui
+++ b/src/gvcore/printdialogpagebase.ui
@@ -24,7 +24,7 @@
</property>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout2</cstring>
+ <cstring>layout2</cstring>
</property>
<hbox>
<property name="name">
@@ -98,7 +98,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>101</width>
<height>21</height>
@@ -170,7 +170,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -186,7 +186,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -214,7 +214,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>240</width>
<height>21</height>
@@ -236,7 +236,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -252,7 +252,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
@@ -351,7 +351,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>16</width>
<height>20</height>
diff --git a/src/gvcore/qxcfi.cpp b/src/gvcore/qxcfi.cpp
index 9fb146a..27ad0b9 100644
--- a/src/gvcore/qxcfi.cpp
+++ b/src/gvcore/qxcfi.cpp
@@ -486,7 +486,7 @@ void XCFImageFormat::readXCF ( TQImageIO* image_io )
}
image_io->setImage( xcf_image.image );
- image_io->setqStatus( 0 );
+ image_io->seStatus( 0 );
}
/*!
diff --git a/src/gvcore/thumbnaildetailsdialogbase.ui b/src/gvcore/thumbnaildetailsdialogbase.ui
index 1dd6646..ae03c98 100644
--- a/src/gvcore/thumbnaildetailsdialogbase.ui
+++ b/src/gvcore/thumbnaildetailsdialogbase.ui
@@ -29,7 +29,7 @@
</widget>
<widget class="TQLayoutWidget">
<property name="name">
- <cstring>tqlayout6</cstring>
+ <cstring>layout6</cstring>
</property>
<grid>
<property name="name">
@@ -45,7 +45,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>20</height>
@@ -96,7 +96,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>21</width>
<height>21</height>
diff --git a/src/gvcore/xpm.cpp b/src/gvcore/xpm.cpp
index cc2cabc..b56ba59 100644
--- a/src/gvcore/xpm.cpp
+++ b/src/gvcore/xpm.cpp
@@ -74,7 +74,7 @@ static TQString fbname( const TQString &fileName ) // get file basename (sort of
s = s.mid( i );
if ( (i = s.findRev('\\')) >= 0 )
s = s.mid( i );
- TQRegExp r( TQString::tqfromLatin1("[a-zA-Z][a-zA-Z0-9_]*") );
+ TQRegExp r( TQString::fromLatin1("[a-zA-Z][a-zA-Z0-9_]*") );
int p = r.search( s );
if ( p == -1 )
s.truncate( 0 );
@@ -82,7 +82,7 @@ static TQString fbname( const TQString &fileName ) // get file basename (sort of
s = s.mid( p, r.matchedLength() );
}
if ( s.isEmpty() )
- s = TQString::tqfromLatin1( "dummy" );
+ s = TQString::fromLatin1( "dummy" );
return s;
}
@@ -161,10 +161,10 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
int i, cpp, ncols, w, h, index = 0;
if ( iio ) {
- iio->setqStatus( 1 );
+ iio->seStatus( 1 );
d = iio ? iio->ioDevice() : 0;
d->readLine( buf.data(), buf.size() ); // "/* XPM */"
- TQRegExp r( TQString::tqfromLatin1("/\\*.XPM.\\*/") );
+ TQRegExp r( TQString::fromLatin1("/\\*.XPM.\\*/") );
if ( buf.find(r) == -1 )
return; // bad magic
} else if ( !source ) {
@@ -291,7 +291,7 @@ static void read_xpm_image_or_array( TQImageIO * iio, const char * const * sourc
}
if ( iio ) {
iio->setImage( image );
- iio->setqStatus( 0 ); // image ok
+ iio->seStatus( 0 ); // image ok
}
}
@@ -340,7 +340,7 @@ static const char* xpm_color_name( int cpp, int index )
static void write_xpm_image( TQImageIO * iio )
{
if ( iio )
- iio->setqStatus( 1 );
+ iio->seStatus( 1 );
else
return;
@@ -424,7 +424,7 @@ static void write_xpm_image( TQImageIO * iio )
}
s << "};" << endl;
- iio->setqStatus( 0 );
+ iio->seStatus( 0 );
}
// TQt code end ---------------------------
diff --git a/src/gvcore/imageview.cpp b/src/gvcore/imageview.cpp
index a6c5b9f..cbfc459 100644
--- a/src/gvcore/imageview.cpp
+++ b/src/gvcore/imageview.cpp
@@ -113,7 +113,7 @@ as approximate as possible). However when converting from widget to image and ba
this can result in the final rectangle being smaller than the original.
The widgetToImageBounding() function converts from widget to image coordinates
in a way which makes sure the reverse conversion will be at least as large
-as the original tqgeometry.
+as the original geometry.
There are no conversion functions for only width/height, as their conversion
depends on the position (because of the rounding etc.). For similar reasons
@@ -257,7 +257,7 @@ struct ImageView::Private {
const double zoomValues[] = { 0.5, 1, 2 };
int nbValues=sizeof(zoomValues) / sizeof(double);
for (int pos=0; pos<nbValues; ++pos) {
- TQString txt=TQString("%1%").tqarg( int(zoomValues[pos]*100) );
+ TQString txt=TQString("%1%").arg( int(zoomValues[pos]*100) );
mZoomCombo->insertItem(txt);
}
}
@@ -423,7 +423,7 @@ ImageView::~ImageView() {
void ImageView::slotLoaded() {
if (d->mDocument->isNull()) {
resizeContents(0,0);
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
return;
}
@@ -488,7 +488,7 @@ KToggleAction* ImageView::zoomToFit() const {
void ImageView::updateFromSettings() {
// Reset, so that next tqrepaint doesn't possibly take longer because of
// smoothing
ImageViewConfig::setMaxRepaintSize(DEFAULT_MAX_REPAINT_SIZE);
ImageViewConfig::setMaxScaleRepaintSize(DEFAULT_MAX_REPAINT_SIZE);
@@ -625,7 +625,7 @@ void ImageView::drawContents(TQPainter* painter,int clipx,int clipy,int clipw,in
TQRect widgetRect = TQRect(0, 0, visibleWidth(), visibleHeight());
TQRegion region = TQRegion(widgetRect) - imageRect;
- TQMemArray<TQRect> rects = region.tqrects();
+ TQMemArray<TQRect> rects = region.rects();
for(unsigned int pos = 0; pos < rects.count(); ++pos ) {
painter->eraseRect(rects[pos]);
}
@@ -701,7 +701,7 @@ void ImageView::limitPaintSize( PendingPaint& paint ) {
// don't paint more than max_size pixels at a time
int maxHeight = ( maxSize + paint.rect.width() - 1 ) / paint.rect.width(); // round up
maxHeight = TQMAX( maxHeight, 5 ); // at least 5 lines together
// can't tqrepaint whole paint at once, adjust height and schedule the rest
if( maxHeight < paint.rect.height()) {
TQRect remaining = paint.rect;
remaining.setTop( remaining.top() + maxHeight );
@@ -781,12 +781,12 @@ void ImageView::slotBusyLevelChanged( BusyLevel level ) {
// How to do painting:
// When something needs to be erased: TQPainter on viewport and eraseRect()
// When whole picture needs to be repainted: fullRepaint()
-// When a part of the picture needs to be updated: viewport()->tqrepaint(area,false)
+// When a part of the picture needs to be updated: viewport()->repaint(area,false)
// All other paints will be changed to progressive painting.
void ImageView::fullRepaint() {
if( !viewport()->isUpdatesEnabled()) return;
cancelPending();
- viewport()->tqrepaint(false);
+ viewport()->repaint(false);
}
void ImageView::cancelPending() {
@@ -832,7 +832,7 @@ void ImageView::performPaint( TQPainter* painter, int clipx, int clipy, int clip
int extraPixels = ImageUtils::extraScalePixels( smoothAlgo, zoom());
TQRect imageRect = d->widgetToImageBounding( TQRect(clipx,clipy,clipw,cliph), extraPixels );
imageRect = imageRect.intersect( TQRect( 0, 0, d->mDocument->width(), d->mDocument->height()));
- TQMemArray< TQRect > rects = TQRegion(d->mValidImageArea.intersect( imageRect )).tqrects();
+ TQMemArray< TQRect > rects = TQRegion(d->mValidImageArea.intersect( imageRect )).rects();
for( unsigned int i = 1; i < rects.count(); ++i ) {
addPendingPaint( secondPass, d->imageToWidget( rects[ i ] ));
}
@@ -1024,7 +1024,7 @@ bool ImageView::eventFilter(TQObject* obj, TQEvent* event) {
return true;
// Getting/loosing focus causes repaints, but repainting here is expensive,
// and there's no need to tqrepaint on focus changes, as the focus is not
// indicated.
case TQEvent::FocusIn:
case TQEvent::FocusOut:
@@ -1313,7 +1313,7 @@ void ImageView::slotImageSizeUpdated() {
void ImageView::slotImageRectUpdated(const TQRect& imageRect) {
d->mValidImageArea += imageRect;
- viewport()->tqrepaint( d->imageToWidget( imageRect ), false );
+ viewport()->repaint( d->imageToWidget( imageRect ), false );
}
@@ -1339,7 +1339,7 @@ double ImageView::computeZoomToFit() const {
return 1.0;
}
TQSize size=d->mDocument->image().size();
- size.tqscale(width(),height(),TQSize::ScaleMin);
+ size.scale(width(),height(),TQSize::ScaleMin);
double zoom=double(size.width())/d->mDocument->width();
if (zoom>1.0 && !ImageViewConfig::enlargeSmallImages()) return 1.0;
@@ -1350,7 +1350,7 @@ double ImageView::computeZoomToWidth() const {
if (d->mDocument->isNull()) {
return 1.0;
}
- int sw = verticalScrollBar()->tqsizeHint().width(); // tqgeometry is not valid before first show()
+ int sw = verticalScrollBar()->sizeHint().width(); // geometry is not valid before first show()
int w = width();
int dw = d->mDocument->width();
switch( vScrollBarMode()) {
@@ -1370,7 +1370,7 @@ double ImageView::computeZoomToHeight() const {
if (d->mDocument->isNull()) {
return 1.0;
}
- int sh = horizontalScrollBar()->tqsizeHint().height();
+ int sh = horizontalScrollBar()->sizeHint().height();
int h = height();
int dh = d->mDocument->height();
switch( vScrollBarMode()) {
@@ -1425,11 +1425,11 @@ void ImageView::updateImageOffset() {
int zpixHeight=int(d->mDocument->height() * d->mZoom);
if (zpixWidth>viewWidth && hScrollBarMode()!=AlwaysOff) {
- // use tqsizeHint() - tqgeometry is not valid before first show()
- viewHeight-=horizontalScrollBar()->tqsizeHint().height();
+ // use sizeHint() - geometry is not valid before first show()
+ viewHeight-=horizontalScrollBar()->sizeHint().height();
}
if (zpixHeight>viewHeight && vScrollBarMode()!=AlwaysOff) {
- viewWidth-=verticalScrollBar()->tqsizeHint().width();
+ viewWidth-=verticalScrollBar()->sizeHint().width();
}
d->mXOffset=TQMAX(0,(viewWidth-zpixWidth)/2);
@@ -1457,7 +1457,7 @@ void ImageView::updateZoomActions() {
if (d->mZoomMode==ZOOM_FREE) {
d->mZoomIn->setEnabled(d->mZoom<MAX_ZOOM);
d->mZoomOut->setEnabled(d->mZoom>1/MAX_ZOOM);
- TQString zoomText=TQString("%1%").tqarg(int(d->mZoom*100));
+ TQString zoomText=TQString("%1%").arg(int(d->mZoom*100));
d->mZoomCombo->setCurrentText(zoomText);
} else {
d->mZoomIn->setEnabled(true);
@@ -488,7 +488,7 @@ KToggleAction* ImageView::zoomToFit() const {
void ImageView::updateFromSettings() {
- // Reset, so that next tqrepaint doesn't possibly take longer because of
+ // Reset, so that next repaint doesn't possibly take longer because of
// smoothing
ImageViewConfig::setMaxRepaintSize(DEFAULT_MAX_REPAINT_SIZE);
@@ -701,7 +701,7 @@ void ImageView::limitPaintSize( PendingPaint& paint ) {
int maxHeight = ( maxSize + paint.rect.width() - 1 ) / paint.rect.width(); // round up
maxHeight = TQMAX( maxHeight, 5 ); // at least 5 lines together
- // can't tqrepaint whole paint at once, adjust height and schedule the rest
+ // can't repaint whole paint at once, adjust height and schedule the rest
if( maxHeight < paint.rect.height()) {
TQRect remaining = paint.rect;
@@ -1024,7 +1024,7 @@ bool ImageView::eventFilter(TQObject* obj, TQEvent* event) {
return true;
// Getting/loosing focus causes repaints, but repainting here is expensive,
- // and there's no need to tqrepaint on focus changes, as the focus is not
+ // and there's no need to repaint on focus changes, as the focus is not
// indicated.
case TQEvent::FocusIn: